@@ -46,11 +46,3 @@ class BaseForm(System.Windows.Forms.Form):
 
     def on_form_closed(self, sender, eargs):
         pass
-
-
-# ==============================================================================
-# Main
-# ==============================================================================
-
-if __name__ == '__main__':
-    pass
